AsyncReadEvent

Enum AsyncReadEvent 

#[non_exhaustive]
pub enum AsyncReadEvent { Samples { generation: u64, data: Vec<u8>, }, Reconfigured { generation: u64, change: AsyncReadConfigChange, }, }
An item produced by an owned asynchronous reader.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Samples

IQ bytes captured under the indicated configuration generation.

Fields

generation: u64
data: Vec<u8>


Reconfigured

An exact stream boundary following a successful configuration change. All subsequent samples carry this generation until the next change.

Fields

generation: u64