pub struct AsyncReadControlHandle { /* private fields */ }Expand description
Cloneable control access to an owned asynchronous reader.
Implementations
Sourceimpl AsyncReadControlHandle
impl AsyncReadControlHandle
Sourcepub fn set_center_freq(&self, frequency: u32) -> Result<u64>
pub fn set_center_freq(&self, frequency: u32) -> Result<u64>
Retunes the receiver and returns the new stream generation.
Sourcepub fn set_tuner_gain(&self, gain: TunerGain) -> Result<u64>
pub fn set_tuner_gain(&self, gain: TunerGain) -> Result<u64>
Changes tuner gain and returns the new stream generation.
Sourcepub fn set_sample_rate(&self, sample_rate: u32) -> Result<u64>
pub fn set_sample_rate(&self, sample_rate: u32) -> Result<u64>
Changes the sample rate and returns the new stream generation.
Sourcepub fn dropped_chunks(&self) -> u64
pub fn dropped_chunks(&self) -> u64
Number of sample chunks dropped because the consumer queue was full.